#ifndef HELPWINDOW_H
#define HELPWINDOW_H
#include <QLabel>
#include <QWidget>
#include <QPixmap>
#include <DraggableViewArea.h>
#include <QMainWindow>
#include <QString>
#include <DisplayPage.h>
#include <QDebug>
#include <QPushButton>
#ifdef Q_WS_MAEMO_5
#include <QMaemo5InformationBox>
#endif

namespace Ui {
    class HelpWindow;
}

class HelpWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit HelpWindow(QWidget *parent = 0);
    ~HelpWindow();
    QWidget *centralwidget;
    Ui::HelpWindow *ui;


public slots:
    void showhelpSlim();
    void showhelpPhat();

private:

};

#endif // HELPWINDOW_H
